@@ -1013,8 +1013,8 @@ tp_detect_jumps(const struct tp_dispatch *tp, struct tp_touch *t)
 	/* called before tp_motion_history_push, so offset 0 is the most
 	 * recent coordinate */
 	last = tp_motion_history_offset(t, 0);
-	dx = fabs(t->point.x - last->x) / tp->device->abs.absinfo_x->resolution;
-	dy = fabs(t->point.y - last->y) / tp->device->abs.absinfo_y->resolution;
+	dx = 1.0 * abs(t->point.x - last->x) / tp->device->abs.absinfo_x->resolution;
+	dy = 1.0 * abs(t->point.y - last->y) / tp->device->abs.absinfo_y->resolution;
 
 	return hypot(dx, dy) > JUMP_THRESHOLD_MM;
 }
@@ -1509,6 +1509,9 @@ tp_dwt_pair_keyboard(struct evdev_device *touchpad,
 	struct tp_dispatch *tp = (struct tp_dispatch*)touchpad->dispatch;
 	unsigned int bus_kbd = libevdev_get_id_bustype(keyboard->evdev);
 
+	if ((keyboard->tags & EVDEV_TAG_KEYBOARD) == 0)
+		return;
+
 	if (!tp_want_dwt(touchpad, keyboard))
 		return;
 
@@ -1536,31 +1539,40 @@ tp_dwt_pair_keyboard(struct evdev_device *touchpad,
 }
 
 static void
-tp_interface_device_added(struct evdev_device *device,
-			  struct evdev_device *added_device)
+tp_pair_trackpoint(struct evdev_device *touchpad,
+			struct evdev_device *trackpoint)
 {
-	struct tp_dispatch *tp = (struct tp_dispatch*)device->dispatch;
-	unsigned int bus_tp = libevdev_get_id_bustype(device->evdev),
-		     bus_trp = libevdev_get_id_bustype(added_device->evdev);
+	struct tp_dispatch *tp = (struct tp_dispatch*)touchpad->dispatch;
+	unsigned int bus_tp = libevdev_get_id_bustype(touchpad->evdev),
+		     bus_trp = libevdev_get_id_bustype(trackpoint->evdev);
 	bool tp_is_internal, trp_is_internal;
 
+	if ((trackpoint->tags & EVDEV_TAG_TRACKPOINT) == 0)
+		return;
+
 	tp_is_internal = bus_tp != BUS_USB && bus_tp != BUS_BLUETOOTH;
 	trp_is_internal = bus_trp != BUS_USB && bus_trp != BUS_BLUETOOTH;
 
 	if (tp->buttons.trackpoint == NULL &&
-	    (added_device->tags & EVDEV_TAG_TRACKPOINT) &&
 	    tp_is_internal && trp_is_internal) {
 		/* Don't send any pending releases to the new trackpoint */
 		tp->buttons.active_is_topbutton = false;
-		tp->buttons.trackpoint = added_device;
+		tp->buttons.trackpoint = trackpoint;
 		if (tp->palm.monitor_trackpoint)
-			libinput_device_add_event_listener(&added_device->base,
+			libinput_device_add_event_listener(&trackpoint->base,
 						&tp->palm.trackpoint_listener,
 						tp_trackpoint_event, tp);
 	}
+}
 
-	if (added_device->tags & EVDEV_TAG_KEYBOARD)
-	    tp_dwt_pair_keyboard(device, added_device);
+static void
+tp_interface_device_added(struct evdev_device *device,
+			  struct evdev_device *added_device)
+{
+	struct tp_dispatch *tp = (struct tp_dispatch*)device->dispatch;
+
+	tp_pair_trackpoint(device, added_device);
+	tp_dwt_pair_keyboard(device, added_device);
 
 	if (tp->sendevents.current_mode !=
 	    LIBINPUT_CONFIG_SEND_EVENTS_DISABLED_ON_EXTERNAL_MOUSE)
